columnEvent constant
String
const columnEvent
The name of the event or action type (e.g., 'attack', 'move').
Implementation
static const String columnEvent = 'event';
The name of the event or action type (e.g., 'attack', 'move').
static const String columnEvent = 'event';