BroadcastStatus enum

The lifecycle state of a transmitted Broadcast transaction.

Inheritance
Available extensions

Values

pending → const BroadcastStatus

The event has been sent by the client but is not yet ordered by the consensus cluster.

confirmed → const BroadcastStatus

The event has been integrated into the global ledger and assigned a sequence position.

failed → const BroadcastStatus

The network cluster rejected the transaction or transmission failed.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BroadcastStatus>
A constant List of the values in this enum, in order of their declaration.